==> magento-6.x-1.1.tar.gz: magento/magento_orders/templates/cart-block.tpl.php <==
<div class="cart_block <?php if (empty($products)) print 'empty'; ?>">
    <?php if ($message) {?>
    	<?php foreach($message as $m) {?>
    	<div class="messages status"><?php print $m;?></div>
    	<?php }?>
    <?php }?>
    <div class="inner">
		<?php if (!empty($products)) {?>
		<div class="item-of">
		    <div class="prize"><?php printf("%01.2f ", $quote['subtotal']);?><?php print $currency;?></div>
		    <div class="item-on"><?php print t('Total de vos achats');?><a href="<?php print url('cart');?>"><?php print t('!count articles', array('!count' => count($products)));?></a></div>
		    <div class="endcol"></div>
		</div>
		<?php }?>
		<?php if($quote['discount_amount']) {?>
		<div class="item-of">
		    <div class="prize"><?php printf("%01.2f ", $quote['discount_amount']);?><?php print $currency;?></div>
		    <div class="item-on"><?php print t('Remise');?></div>
		    <div class="endcol"></div>
		</div>
		<?php }?>
		<?php if($quote['taxes']) {?>
        	<?php $tax_amount = 0;?>
            <?php foreach ($quote['taxes'] as $tax) {
              	$tax_amount += $tax['amount'];
            }?>
      		<div class="item-of">
      		    <div class="prize"><?php printf("%01.2f ", $tax_amount);?><?php print $currency;?></div>
      		    <div class="item-on"><?php print t('Taxes');?></div>
      		    <div class="endcol"></div>
      		</div>
		<?php }?>
		<?php if($quote['grand_total']) {?>
		<div class="item-of">
		    <div class="prize"><?php printf("%01.2f ", $quote['grand_total']);?><?php print $currency;?></div>
		    <div class="item-on"><?php print t('Total de la commande');?></div>
		    <div class="endcol"></div>
		</div>
		<?php }?>
		<div class="btn">
		    <div class="prize">
			    <div class="rol-img">
				    <img src="<?php print base_path().drupal_get_path('theme', 'cigale'); ?>/images/btns/btn_pink_valider.gif" alt="" />
				    <a href="<?php print url('cart');?>"><img src="<?php print base_path().drupal_get_path('theme', 'cigale'); ?>/images/btns/btn_pink_valider_act.gif" class="rol" alt="" /></a>
			    </div>
		    </div>
		    <div class="item-on"><a href="<?php print url('cart');?>"><?php print t('Modifier');?></a></div>
		    <div class="endcol"></div>
		</div>
	</div>
</div>

==> magento-6.x-1.3.tar.gz: magento/magento_orders/templates/cart-block.tpl.php <==
<div class="cart_block <?php if (empty($products)) print 'empty'; ?>">
    <?php if ($message) {?>
    	<?php foreach($message as $m) {?>
    	<div class="messages status"><?php print $m;?></div>
    	<?php }?>
    <?php }?>
    <div class="inner">
		<?php if (!empty($products) && $quote['subtotal']) {?>
		<div class="item-of">
		    <div class="prize"><?php printf("%01.2f ", $quote['subtotal']);?><?php print $currency;?></div>
		    <div class="item-on"><?php print t('Total purchases ');?><a href="<?php print url('cart');?>"><?php print t('!count articles', array('!count' => count($products)));?></a></div>
		    <div class="endcol"></div>
		</div>
		<?php }?>
		<?php if(!empty($products) && $quote['discount_amount']) {?>
		<div class="item-of">
		    <div class="prize"><?php printf("%01.2f ", $quote['discount_amount']);?><?php print $currency;?></div>
		    <div class="item-on"><?php print t('Discount');?></div>
		    <div class="endcol"></div>
		</div>
		<?php }?>
		<?php if(!empty($products) && $quote['taxes']) {?>
        	<?php $tax_amount = 0;?>
            <?php foreach ($quote['taxes'] as $tax) {
              	$tax_amount += $tax['amount'];
            }?>
      		<div class="item-of">
      		    <div class="prize"><?php printf("%01.2f ", $tax_amount);?><?php print $currency;?></div>
      		    <div class="item-on"><?php print t('Taxes');?></div>
      		    <div class="endcol"></div>
      		</div>
		<?php }?>
		<?php if(!empty($products) && $quote['grand_total']) {?>
		<div class="item-of">
		    <div class="prize"><?php printf("%01.2f ", $quote['grand_total']);?><?php print $currency;?></div>
		    <div class="item-on"><?php print t('Total order');?></div>
		    <div class="endcol"></div>
		</div>
		<div class="btn">
		    <div class="item-on"><a href="<?php print url('cart');?>"><?php print t('Edit');?></a></div>
		    <div class="endcol"></div>
		</div>
		<?php }?>
	</div>
</div>
